==> giraffez-1.0.2.tar.gz: giraffez-1.0.2/giraffez/climodule.c <==
/*
 * Copyright 2016 Capital One Services, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Python.h>
#include <signal.h>
#include "compat.h"


#include "cmdobject.h"


#ifdef __cplusplus
extern "C" {
#endif 


static int py_quit(void* n) {
    Py_Exit(1);
    return -1;
}

static void py_cold_shutdown(int signum) {
    fprintf(stderr, "*** Received SIGINT. Closing ...\n");
    // Py_Exit() is added as a pending call just in case the Python main
    // thread has any chance of finalizing. This will not allow for any
    // __exit__ code to run if it is successful in completing Py_Exit.
    // If unsuccessful, the standard C exit() function is called since
    // this code is reached when the user wants the process to end
    // regardless of the state of any open connections.
    PyGILState_STATE state = PyGILState_Ensure();
    Py_AddPendingCall(&py_quit, NULL);
    PyGILState_Release(state);
    PyErr_SetInterrupt();
    exit(1);
}

static void default_signal_handler(int signum) {
    fprintf(stderr, "\n*** Received SIGINT. Shutting down (clean) ...\n");
    // GIL must be acquired before setting interrupt
    PyGILState_STATE state = PyGILState_Ensure();
    // Interrupt sent to Python main thread
    PyErr_SetInterrupt();
    PyGILState_Release(state);

    // Set secondary interrupt to allow for improper shutdown
    signal(SIGINT, py_cold_shutdown);
}

static PyMethodDef module_methods[] = {
    {NULL}  /* Sentinel */
};

MOD_INIT(_cli)
{
    PyObject* m;

    signal(SIGINT, &default_signal_handler);
    signal(SIGTERM, &default_signal_handler);

    if (PyType_Ready(&CmdType) < 0) {
        return MOD_ERROR_VAL;
    }

    MOD_DEF(m, "_cli", "", module_methods);

    if (m == NULL) {
        return MOD_ERROR_VAL;
    }

    GiraffeError = PyErr_NewException((char*)"_cli.error", NULL, NULL);
    Py_INCREF(GiraffeError);
    PyModule_AddObject(m, "error", GiraffeError);

    Py_INCREF(&CmdType);
    PyModule_AddObject(m, "Cmd", (PyObject*)&CmdType);
    return MOD_SUCCESS_VAL(m);
}

#ifdef __cplusplus
}
#endif

==> giraffez-1.0.4.tar.gz: giraffez-1.0.4/giraffez/climodule.c <==
/*
 * Copyright 2016 Capital One Services, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Python.h>
#include "compat.h"


#include "cmdobject.h"


#ifdef __cplusplus
extern "C" {
#endif 


static PyMethodDef module_methods[] = {
    {NULL}  /* Sentinel */
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef moduledef = {
    PyModuleDef_HEAD_INIT, "_cli", "", -1, module_methods
};
#endif

MOD_INIT(_cli)
{
    PyObject* m;

    if (PyType_Ready(&CmdType) < 0) {
        return MOD_ERROR_VAL;
    }

#if PY_MAJOR_VERSION >= 3
    m = PyModule_Create(&moduledef);
#else
    m = Py_InitModule("_cli", module_methods);
#endif

    if (m == NULL) {
        return MOD_ERROR_VAL;
    }

    GiraffeError = PyErr_NewException((char*)"_cli.error", NULL, NULL);
    Py_INCREF(GiraffeError);
    PyModule_AddObject(m, "error", GiraffeError);

    Py_INCREF(&CmdType);
    PyModule_AddObject(m, "Cmd", (PyObject*)&CmdType);
    return MOD_SUCCESS_VAL(m);
}

#ifdef __cplusplus
}
#endif
